module("dataminer", package.seeall)

-- $Author: bam $
-- $Date: 2007-05-06 12:14:35 -0400 (Sun, 06 May 2007) $ 
-- $Revision: 34637 $

local string, table = string, table
local format, match, gmatch = string.format, string.match, string.gmatch
local insert = table.insert
local sort = function(t, ...) table.sort(t, ...) return t end

local http = require "socket.http"


function read_items(filename)
  local datafile, err = io.open(filename, "r")
  assert(datafile, err)
  local data = {}
  for line in datafile:lines() do
    local id, price, name = match(line, "^(%d+)\t(%d*)\t(.+)$")
    if id then data[tonumber(id)] = {price = tonumber(price), name = name} end
  end
  datafile:close()
  return data
end

function write_items(filename, items)
  local datafile, err = io.open(filename, "w+")
  assert(datafile, err)
  local count = 0
  for id = 1, table.maxn(items) do
    local item = items[id]
    if item then
      local price, name = item.price, item.name
      datafile:write(format("%d\t%s\t%s\n", id, price and tostring(price) or "", name))
      count = count + 1
    end
  end
  datafile:close()
  print(format("Wrote %d items to %s", count, filename))
end

function get_page(url)
  print(format("Fetching page from %s", url))
  local r, e = http.request(url)
  assert(r, e)
  return r
end

function item_url(id)
  return format("http://www.wowhead.com/?item=%d", id)
end

function scan_item_urls(page)
  local items, seen = {}, {}
  for idstr in gmatch(page, "?item=(%d+)") do
    if not seen[idstr] then 
      seen[idstr] = true
      insert(items, tonumber(idstr))
    end
  end
  return sort(items)
end

local function scan_coin(str, coinName)
  return tonumber(match(str, format('money%s%%D-(%%d+)', coinName))) or 0
end

function scan_item_page(page, id)
  local name = match(page, "<title>%s*(.-)%s+-%s+Items%s+-%s+World%sof%sWarcraft</title>")
  if not name or name == "" then print(format("Skipping item:%d: Could not find item name!", id)) return end
  local money_div = match(page, "<%s*div%s*>%s*Sells%s+for%s*(.-)%s*</%s*div%s*>")
  if not money_div or money_div == "" then return name end
  local g, s, c = scan_coin(money_div, "gold"), scan_coin(money_div, "silver"), scan_coin(money_div, "copper")
  return name, g*10000 + s*100 + c
end




