#!/usr/bin/env lua

-- $Author: bam $
-- $Date: 2007-05-06 17:01:55 -0400 (Sun, 06 May 2007) $ 
-- $Revision: 34660 $

local string, table = string, table
local format, match, gmatch = string.format, string.match, string.gmatch
local insert = table.insert
local sort = function(t, ...) table.sort(t, ...) return t end

local dataminer = require "dataminer"
local read_items, write_items, get_page, scan_item_urls, scan_item_page, item_url = 
      dataminer.read_items, dataminer.write_items, dataminer.get_page, dataminer.scan_item_urls, dataminer.scan_item_page, dataminer.item_url

local arg_items = {}
for _, a in ipairs(arg) do
  local id = tonumber(a)
  if id then
    arg_items[id] = true
  else
    local id1s, id2s = match(a, "^(%d+)-(%d+)$")
    if id1s then
      for id = tonumber(id1s), tonumber(id2s) do
        arg_items[id] = true
      end
    else
      arg_items[a] = true
    end
  end
end


local new_item_urls = {}
for a in pairs(arg_items) do
  local id = tonumber(a)
  if id then insert(new_item_urls, id) end
end
local new_count = #new_item_urls
if new_count == 0 then print("Nothing to do! Stop bothering me!") return end
print(format("Preparing to scan %d item urls...", new_count))

local items = read_items("items.csv")

for i, id in ipairs(new_item_urls) do
  local page = get_page(item_url(id))
  local name, price = scan_item_page(page, id)
  if name then 
    print(format(" *%6s: Found %q (%d) = %s", tostring(i), name, id, price and tostring(price) or "(no price)")) 
    local old_item = items[id]
    if not old_item then
      print("** BRAND NEW ITEM **")
    elseif old_item.price then
      if price then
        if old_item.price ~= price then
          print("** PRICE CHANGED **")
        end
      end
    elseif price then
      print("** PRICE FOUND **")
    end

    items[id] = {price = price or old_item.price, name = name}
  end
end

os.execute("cp items.csv items.bak")
write_items("items.csv", items)




